@@ -130,68 +130,6 @@ cfg.CONF.register_group(api_cfn_group)
 cfg.CONF.register_opts(api_cfn_opts,
                        group=api_cfn_group)
 
-api_cw_opts = [
-    cfg.IPOpt('bind_host', default='0.0.0.0',
-              help=_('Address to bind the server. Useful when '
-                     'selecting a particular network interface.'),
-              deprecated_group='DEFAULT',
-              deprecated_for_removal=True,
-              deprecated_reason='Heat CloudWatch API has been removed.',
-              deprecated_since='10.0.0'),
-    cfg.PortOpt('bind_port', default=8003,
-                help=_('The port on which the server will listen.'),
-                deprecated_group='DEFAULT',
-                deprecated_for_removal=True,
-                deprecated_reason='Heat CloudWatch API has been removed.',
-                deprecated_since='10.0.0'),
-    cfg.IntOpt('backlog', default=4096,
-               help=_("Number of backlog requests "
-                      "to configure the socket with."),
-               deprecated_group='DEFAULT',
-               deprecated_for_removal=True,
-               deprecated_reason='Heat CloudWatch API has been removed.',
-               deprecated_since='10.0.0'),
-    cfg.StrOpt('cert_file',
-               help=_("Location of the SSL certificate file "
-                      "to use for SSL mode."),
-               deprecated_group='DEFAULT',
-               deprecated_for_removal=True,
-               deprecated_reason='Heat CloudWatch API has been Removed.',
-               deprecated_since='10.0.0'),
-    cfg.StrOpt('key_file',
-               help=_("Location of the SSL key file to use "
-                      "for enabling SSL mode."),
-               deprecated_group='DEFAULT',
-               deprecated_for_removal=True,
-               deprecated_reason='Heat CloudWatch API has been Removed.',
-               deprecated_since='10.0.0'),
-    cfg.IntOpt('workers', min=0, default=1,
-               help=_("Number of workers for Heat service."),
-               deprecated_group='DEFAULT',
-               deprecated_for_removal=True,
-               deprecated_reason='Heat CloudWatch API has been Removed.',
-               deprecated_since='10.0.0'),
-    cfg.IntOpt('max_header_line', default=16384,
-               help=_('Maximum line size of message headers to be accepted. '
-                      'max_header_line may need to be increased when using '
-                      'large tokens (typically those generated by the '
-                      'Keystone v3 API with big service catalogs.)'),
-               deprecated_for_removal=True,
-               deprecated_reason='Heat CloudWatch API has been Removed.',
-               deprecated_since='10.0.0'),
-    cfg.IntOpt('tcp_keepidle', default=600,
-               help=_('The value for the socket option TCP_KEEPIDLE.  This is '
-                      'the time in seconds that the connection must be idle '
-                      'before TCP starts sending keepalive probes.'),
-               deprecated_for_removal=True,
-               deprecated_reason='Heat CloudWatch API has been Removed.',
-               deprecated_since='10.0.0')
-]
-api_cw_group = cfg.OptGroup('heat_api_cloudwatch')
-cfg.CONF.register_group(api_cw_group)
-cfg.CONF.register_opts(api_cw_opts,
-                       group=api_cw_group)
-
 wsgi_elt_opts = [
     cfg.BoolOpt('wsgi_keep_alive',
                 default=True,
@@ -218,7 +156,6 @@ def list_opts():
     yield None, [json_size_opt]
     yield 'heat_api', api_opts
     yield 'heat_api_cfn', api_cfn_opts
-    yield 'heat_api_cloudwatch', api_cw_opts
     yield 'eventlet_opts', wsgi_elt_opts
 
 
@@ -263,7 +200,7 @@ def get_socket(conf, default_port):
                                    backlog=conf.backlog,
                                    family=address_family)
         except socket.error as err:
-            if err.args[0] != errno.EADDRINUSE:
+            if err.errno != errno.EADDRINUSE:
                 raise
             eventlet.sleep(0.1)
     if not sock:
@@ -584,7 +521,7 @@ class Server(object):
                 keepalive=cfg.CONF.eventlet_opts.wsgi_keep_alive,
                 socket_timeout=socket_timeout)
         except socket.error as err:
-            if err[0] != errno.EINVAL:
+            if err.errno != errno.EINVAL:
                 raise
         self.pool.waitall()
 
