@@ -220,7 +220,7 @@ def format_stack(stack, preview=False, resolve_outputs=True):
         rpc_api.STACK_OWNER: stack.username,
         rpc_api.STACK_PARENT: stack.owner_id,
         rpc_api.STACK_USER_PROJECT_ID: stack.stack_user_project_id,
-        rpc_api.STACK_TAGS: stack.tags or None,
+        rpc_api.STACK_TAGS: stack.tags,
     }
 
     if not preview:
@@ -243,7 +243,7 @@ def format_stack(stack, preview=False, resolve_outputs=True):
 def format_stack_db_object(stack):
     """Return a summary representation of the given stack.
 
-    Given a stack versioned db object, return a representation of the given
+    Given a stack versioned DB object, return a representation of the given
     stack for a stack listing.
     """
     updated_time = heat_timeutils.isotime(stack.updated_at)
@@ -292,7 +292,7 @@ def format_resource_attributes(resource, with_attr=None):
     if 'show' in resolver:
         show_attr = resolve('show', resolver)
         # check if 'show' resolved to dictionary. so it's not None
-        if isinstance(show_attr, collections.Mapping):
+        if isinstance(show_attr, collections.abc.Mapping):
             for a in with_attr:
                 if a not in show_attr:
                     show_attr[a] = resolve(a, resolver)
