@@ -14,6 +14,7 @@
 from cinderclient import client as cc
 from cinderclient import exceptions
 from keystoneauth1 import exceptions as ks_exceptions
+from oslo_config import cfg
 from oslo_log import log as logging
 
 from heat.common import exception
@@ -28,11 +29,12 @@ LOG = logging.getLogger(__name__)
 CLIENT_NAME = 'cinder'
 
 
-class CinderClientPlugin(client_plugin.ClientPlugin):
+class CinderClientPlugin(os_client.ExtensionMixin,
+                         client_plugin.ClientPlugin):
 
     exceptions_module = exceptions
 
-    service_types = [VOLUME_V2, VOLUME_V3] = ['volumev2', 'volumev3']
+    service_types = [VOLUME_V3] = ['volumev3']
 
     def get_volume_api_version(self):
         '''Returns the most recent API version.'''
@@ -44,14 +46,7 @@ class CinderClientPlugin(client_plugin.ClientPlugin):
             self.service_type = self.VOLUME_V3
             self.client_version = '3'
         except ks_exceptions.EndpointNotFound:
-            try:
-                self.context.keystone_session.get_endpoint(
-                    service_type=self.VOLUME_V2,
-                    interface=self.interface)
-                self.service_type = self.VOLUME_V2
-                self.client_version = '2'
-            except ks_exceptions.EndpointNotFound:
-                raise exception.Error(_('No volume service available.'))
+            raise exception.Error(_('No volume service available.'))
 
     def _create(self):
         self.get_volume_api_version()
@@ -62,6 +57,7 @@ class CinderClientPlugin(client_plugin.ClientPlugin):
             'interface': self.interface,
             'service_type': self.service_type,
             'region_name': self._get_region_name(),
+            'connect_retries': cfg.CONF.client_retry_limit,
             'http_log_debug': self._get_client_option(CLIENT_NAME,
                                                       'http_log_debug')
         }
@@ -74,10 +70,6 @@ class CinderClientPlugin(client_plugin.ClientPlugin):
         extensions = self.client().list_extensions.show_all()
         return set(extension.alias for extension in extensions)
 
-    def has_extension(self, alias):
-        """Check if specific extension is present."""
-        return alias in self._list_extensions()
-
     def get_volume(self, volume):
         try:
             return self.client().volumes.get(volume)
