@@ -277,13 +277,13 @@ class KsClientWrapper(object):
         return trust_context
 
     def _get_username(self, username):
-        if(len(username) > 255):
+        if len(username) > 255:
             LOG.warning("Truncating the username %s to the last 255 "
                         "characters.", username)
         # get the last 255 characters of the username
         return username[-255:]
 
-    def create_stack_user(self, username, password=''):
+    def create_stack_user(self, username, password):
         """Create a user defined as part of a stack.
 
         The user is defined either via template or created internally by a
