@@ -40,6 +40,8 @@ resources:
       segmentation_id: 101
       router_external: False
       shared: true
+      availability_zone_hints:
+        - az1
       tags:
         - tag1
         - tag2
@@ -128,7 +130,8 @@ class NeutronProviderNetTest(common.HeatTestCase):
                 'provider:physical_network': 'physnet_1',
                 'provider:segmentation_id': '101',
                 'router:external': False,
-                'shared': True
+                'shared': True,
+                'availability_zone_hints': ['az1'],
             }
         })
         self.mockclient.replace_tag.assert_called_with(
@@ -180,7 +183,8 @@ class NeutronProviderNetTest(common.HeatTestCase):
                 'provider:physical_network': 'physnet_1',
                 'provider:segmentation_id': '101',
                 'router:external': False,
-                'shared': True}
+                'shared': True,
+                'availability_zone_hints': ['az1']}
         })
         self.mockclient.replace_tag.assert_called_with(
             resource_type,
@@ -243,6 +247,7 @@ class NeutronProviderNetTest(common.HeatTestCase):
             'port_security_enabled': True,
             'segmentation_id': None,
             'router_external': False,
+            'availability_zone_hints': [],
             'tags': ['tag1', 'tag2'],
         }
 
