@@ -32,6 +32,7 @@ from heat.engine import rsrc_defn
 from heat.engine import stack as parser
 from heat.engine import support
 from heat.engine import template
+from heat.objects import stack as stack_object
 from heat.tests import common
 from heat.tests import generic_resource as generic_rsrc
 from heat.tests import utils
@@ -972,6 +973,10 @@ class TemplateResourceCrudTest(common.HeatTestCase):
                                                       self.defn, self.stack)
         self.assertIsNone(self.res.validate())
 
+        self.patchobject(stack_object.Stack, 'get_status',
+                         return_value=('CREATE', 'COMPLETE',
+                                       'Created', 'Sometime'))
+
     def test_handle_create(self):
         self.res.create_with_template = mock.Mock(return_value=None)
 
